tonalitytools.is_unlikely_melodic_diatonic_interval_in_chorale
==============================================================

.. autofunction:: abjad.tools.tonalitytools.is_unlikely_melodic_diatonic_interval_in_chorale.is_unlikely_melodic_diatonic_interval_in_chorale
